package de.intevation.flys.artifacts.model.minfo;

import gnu.trove.TDoubleArrayList;

import java.util.Calendar;
import java.util.Date;
import java.util.List;

import net.sf.ehcache.Cache;
import net.sf.ehcache.Element;

import org.apache.log4j.Logger;
import org.hibernate.SQLQuery;
import org.hibernate.Session;
import org.hibernate.type.StandardBasicTypes;

import de.intevation.flys.artifacts.cache.CacheFactory;
import de.intevation.flys.model.FlowVelocityMeasurement;
import de.intevation.flys.model.FlowVelocityMeasurementValue;
import de.intevation.flys.backend.SessionHolder;


public class FlowVelocityMeasurementFactory
{
    /** Private logger to use here. */
    private static Logger log = Logger.getLogger(FlowVelocityMeasurementFactory.class);

    /** Query to get description and start year, given name and a km range. */
    public static final String SQL_SELECT_ONE =
        "SELECT station, datetime, w, q, v, description " +
        "   FROM flow_velocity_measure_values" +
        "   WHERE id = :id";


    private FlowVelocityMeasurementFactory() {
    }


    public static FlowVelocityMeasurementValue.FastFlowVelocityMeasurementValue
        getFlowVelocityMeasurement(int id)
    {
        log.debug("FlowVelocityMeasurementFactory.getFlowVelocityMeasurementValue");
        Session session = SessionHolder.HOLDER.get();
        SQLQuery sqlQuery = null;
        sqlQuery = session.createSQLQuery(SQL_SELECT_ONE);
        sqlQuery.setParameter("id", id);

        List<Object []> results = sqlQuery.list();
        if (results.size() > 0) {
            Object[] row = results.get(0);
            if (row == null || row.length < 6) {
                return null;
            }
            return FlowVelocityMeasurementValue.getUnmapped(
                Double.parseDouble(row[0].toString()),
                Double.parseDouble(row[2].toString()),
                Double.valueOf(row[3].toString()),
                Double.valueOf(row[4].toString()), null, row[5].toString());
        }
        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
